@@ -11,9 +11,10 @@ import itertools
 import json
 import random
 import re
+import sys
 from base64 import b64encode
 
-from .constants import _20MHZ_CHANNEL_LIST
+from lswifi.constants import _6GHZ_20MHZ_CHANNEL_LIST, _20MHZ_CHANNEL_LIST
 
 __control_chars = "".join(
     map(chr, itertools.chain(range(0x00, 0x20), range(0x7F, 0xA0)))
@@ -61,6 +62,14 @@ def get_attr_max_len(ies, attr):
     return max(len(x) for x in _list)
 
 
+def get_index(key: str, results: list):
+    for r in results:
+        for i, x in enumerate(r):
+            if key in str(x.header):
+                return i
+    return -1
+
+
 def bytes_to_int(x_bytes):
     return int.from_bytes(x_bytes, "big")
 
@@ -191,6 +200,26 @@ def get_channel_number_from_frequency(frequency):
         return "Unknown"
 
 
+def twos(val, bytes):
+    b = val.to_bytes(bytes, byteorder=sys.byteorder, signed=False)
+    return int.from_bytes(b, byteorder=sys.byteorder, signed=True)
+
+
+def get_6ghz_frequency_from_channel_number(channel_number: str) -> str:
+    """gets the center frequency for a corresponding channel
+
+    Args:
+        channel_number (int): 802.11 channel number
+
+    Returns:
+        str: frequency
+    """
+    for key, value in _6GHZ_20MHZ_CHANNEL_LIST.items():
+        if channel_number == value:
+            return key
+    return "Unknown"
+
+
 class Base64Encoder(json.JSONEncoder):
     """A Base64 encoder for JSON"""
 
